file=Makefile
echo "Extracting $file"
rm -f $file
tarfile=pari-$revision.tar

file=Makefile.$osname-$arch$suffix
ln -s $file Makefile 
rm -f $file

if test -n "$GP_INSTALL_PREFIX"; then
  date=`date +%Y%m%d%H%M`; date="-t $date"
fi

cat > $file << EOT
#
# This file was created by Configure. All changes made will be lost
# next time Configure is run.
#
RM = /bin/rm -f

dft target::
	@echo "Possible targets are :"
	@echo "	gp			Compilation"
	@echo "	bench, test 		Compilation and test"
	@echo "	doc			Documentation"
	@echo "	install			Installation"
	@echo "For pari maintainers..."
	@echo "	all			Compile gp-sta gp-dyn lib-sta lib-dyn"
	@echo "	distrib			For distribution of pari/gp"
	@echo "	bigdistrib		Idem, with all directories"
	@echo "	exp			Copy of the sources for experimental release"
	@echo "	rel			New release"
	@echo "	patch			Experimental diff file"
	@echo "	undo			Undo experimental release"

gp all ftest bench test test-compat test-graphic install clean install-bin install-lib-sta install-bin-sta::
	cd $objdir; \$(MAKE) \$@

doc::
	cd doc; \$(MAKE)

undo::
	@\$(RM) Configure; mv Configure.orig Configure
	@for dir in configure src doc perl; do \$(RM) -r \$\$dir; \\
	   mv \$\$dir.orig \$\$dir; done
	@\$(RM) exp

exp::
	@for dir in configure src doc perl; do if test -d \$\$dir.orig; then \\
	   echo "Remove \$\$dir.orig before building an experimental release";\\
	   exit 1; fi; done
	for dir in configure src doc perl; do \\
	   mv \$\$dir \$\$dir.orig; cp -pr \$\$dir.orig \$\$dir; done
	ln -s src exp
	sed "s,patch_level=.*,patch_level=exp," \\
	    < configure.orig/version > configure/version

patch:: pl$next_patch
pl$next_patch:
	@if diff -c src exp >/dev/null 2>/dev/null; then :; else \\
	   echo "'src' should be a link to 'exp'"; exit 1; fi
	-diff -c Configure.orig Configure > pl$next_patch
	@for dir in configure src doc perl; do \\
	   echo "diff -c \$\$dir.orig \$\$dir"; \\
	   for i in \`find \$\$dir -type f -print\`; do \\
	   diff -c \`echo \$\$i|sed s,\$\$dir/,\$\$dir.orig/,\` \$\$i; \\
	   done >> pl$next_patch; done

update-version::
	sed -e "s,^patch_level=.*,patch_level=$next_patch," \\
	    -e "s,^next_patch=.*,next_patch=`expr $next_patch + 1`," \\
	  < configure.orig/version > configure/version

rel: update-version pl$next_patch
	\$(RM) exp

RCS::
	cd src; ci -f -l -r\$\${REVISION:-$rcsrevision} -m"." */*.[chs] test/in
	cd src; /bin/touch -m $date */*.[chs]

setdir::
	@dir=pari-$revision; if test -d \$\$dir; then \\
	   echo "Remove \$\$dir before building a new release"; exit 1;\\
	fi;\\
	mkdir \$\$dir; mv $tarfile \$\$dir; \\
	cd \$\$dir; tar xf $tarfile; \$(RM) $tarfile; cd ..; \\
	tar cf $tarfile \$\$dir; \\
	rm -r \$\$dir

bigdistrib: bigtar setdir
	gzip $tarfile

uu: bigdistrib
	uuencode $tarfile.gz $tarfile.gz > pari.uu

distrib: tar setdir
	gzip $tarfile

bigtar: tar
	tar rf $tarfile doc/gp.1 doc/tutorial.tex doc/app* doc/usersch* \
          doc/macros.tex.in doc/macrosbig.tex doc/Makefile doc/refcard.tex \
          doc/users.tex doc/users.help.tex

tar::
EOT
case "`tar 2>&1`" in
  *"--help"*) cat >> $file << EOT
	tar cfXT $tarfile $config_dir/tar_exclude $config_dir/tar_include
EOT
;;
  *) cat >> $file << EOT
	tar FcfX $tarfile $config_dir/tar_exclude -I $config_dir/tar_include
EOT
;;
esac
